@@ -14,17 +14,19 @@ def processDataExtensionBatch(batch):
     idcol = normalizeDBcol(idcol)
 
     ids, props = tuple(batch[x] for x in ('ids', 'properties'))
-    cols = tuple(p['name'] for p in props)
+    cols = {normalizeDBcol(p['id']): p['id'] for p in props}
     db = get_db()
     cur = db.cursor()
 
     # Could use some defensiveness in generating this SQL
     cur.execute(
         "SELECT %s,%s FROM data WHERE %s in (%s)" %
-        (idcol, ','.join(cols), idcol, ','.join('?' * len(ids))), ids)
+        (idcol, ','.join(cols.keys()), idcol, ','.join('?' * len(ids))), ids)
 
     rows = dict()
     for row in cur:
-        rows[row[idcol]] = dict((col, [{'str': row[col]}]) for col in cols)
+        rows[row[idcol]] = {cols[col]: [{'str': row[col]}] for col in cols}
 
-    return dict(meta=props, rows=rows)
+    meta = [dict(id=p['id'], name=p['id']) for p in props]
+
+    return dict(meta=meta, rows=rows)
